@@ -46,12 +46,23 @@ Note that this distribution’s interface can still change. If you decide
 to use CBOR::PP in your project, please always check the changelog before
 upgrading.
 
+=head1 FRACTIONAL (FLOATING-POINT) NUMBERS
+
+Floating-point numbers are encoded in CBOR as IEEE 754 half-, single-,
+or double-precision. If your Perl is compiled to use “long double”
+floating-point numbers, you may see rounding errors when converting
+to/from CBOR. If that’s a problem for you, append an empty string to
+your floating-point numbers, which will cause CBOR::PP to encode
+them as strings.
+
 =head1 SEE ALSO
 
 L<CBOR::Free> is a B<much> faster, XS-based encoder/decoder.
 
 L<CBOR::XS> isn’t quite as fast as CBOR::Free but is older and
-(as of this writing) more widely used.
+(as of this writing) more widely used. It’s also technically unsupported
+on current Perl versions, though, and its GPL license makes it
+useful only for open-source projects.
 
 =head1 AUTHOR
 
@@ -65,7 +76,7 @@ This code is licensed under the same license as Perl itself.
 
 #----------------------------------------------------------------------
 
-our $VERSION = '0.01_03';
+our $VERSION = '0.04_01';
 
 use CBOR::PP::Encode ();
 use CBOR::PP::Decode ();
